import { ICollectionRef, IBulk } from "./types";
declare type IWriteQueries = "set" | "update" | "delete" | "add";
declare type ICollectionQueries = "get" | "add" | "keys" | "delete-collection" | "list";
declare type IDocumentQueries = "get" | "set" | "update" | "delete";
declare type ICallQueryTypes = IWriteQueries | ICollectionQueries | IDocumentQueries | "snapshot" | "unsubscribe";
interface ITypedQuery<T> {
    path: string[];
    type: T;
    data?: any;
    options?: any;
}
declare abstract class Snapshot<T> {
    protected id: string;
    isSubscribed: boolean;
    abstract subscribe(): Promise<() => void>;
    abstract unsubscribe(): void;
    abstract receivedData(data: T): void;
    abstract resubscribe(): void;
    abstract destroy(): void;
}
declare const QueryRequest: unique symbol;
declare const Snapshots: unique symbol;
export declare class OfflineError extends Error {
    constructor();
}
export default class Database {
    static WebSocket: typeof WebSocket;
    private offlineObersvable;
    get offline(): {
        subscribe: (callback: import("@hibas123/utils").ObserverCallback<boolean>) => () => void;
        unsubscribe: (callback: import("@hibas123/utils").ObserverCallback<boolean>) => void;
        awaitValue: (value: boolean) => PromiseLike<void> & {
            catch: (cb: (err: any) => PromiseLike<void>) => PromiseLike<void>;
            ignore: () => void;
        };
        state: boolean;
    };
    private socket;
    private requests;
    private url;
    constructor(url: string, database: string, accesskey?: string, authkey?: string, rootkey?: string);
    private _connect;
    [Snapshots]: Map<string, Snapshot<any>>;
    private handleSnapshot;
    private handleResponse;
    [QueryRequest]<T = any>(query?: ITypedQuery<ICallQueryTypes> | ITypedQuery<"set" | "update" | "delete">[], id?: string, ns?: string): Promise<T>;
    collection<T = any>(name: string): ICollectionRef<T>;
    collections(): Promise<ICollectionRef[]>;
    bulk(): IBulk;
    close(): void;
}
export {};
